@@ -39,6 +39,11 @@ func readConfig() {
 		Log: srunModels.Log{
 			FilePath: "./",
 		},
+		DDNS: srunModels.DDNS{
+			Enable: false,
+			TTL:    600,
+			Domain: "www.example.com",
+		},
 	})
 
 	//生成配置文件
