@@ -1,6 +1,7 @@
 package main
 
 import (
+	"fmt"
 	"github.com/Mmx233/BitSrunLoginGo/controllers"
 	"github.com/Mmx233/BitSrunLoginGo/global"
 	"github.com/Mmx233/BitSrunLoginGo/util"
@@ -18,16 +19,20 @@ func main() {
 		//登录流程
 		var err error
 		if global.Config.Settings.Basic.Interfaces == "" { //单网卡
-			if err = controllers.Login(nil); err != nil {
-				log.Fatalln("运行出错，状态异常: ", err)
+			if err = controllers.Login(nil, false); err != nil {
+				log.Errorln("登录出错: ", err)
+				if !global.Config.Settings.Log.DebugLevel {
+					fmt.Printf("开启调试日志（debug_level）获取详细信息")
+				}
+				return
 			}
 		} else { //多网卡
-			log.Debugln("多网卡模式")
+			log.Infoln("多网卡模式")
 			interfaces, _ := util.GetInterfaceAddr()
 			for _, eth := range interfaces {
-				log.Infoln("网卡: ", eth.Name)
-				if err = controllers.Login(eth.Addr); err != nil {
-					log.Errorln("运行出错，状态异常: ", err)
+				log.Infoln("使用网卡: ", eth.Name)
+				if err = controllers.Login(eth.Addr, false); err != nil {
+					log.Errorf("网卡 %s 登录出错: %v", eth.Name, err)
 				}
 			}
 		}
